# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class GetProviderCapabilitiesExpandOptions(str, enum.Enum):
    CONNECTOR = "connector"
    OPERATIONS = "operations"
    REQUEST_BODY = "request_body"
    PROVIDER_CONFIG = "provider_config"

    def visit(
        self,
        connector: typing.Callable[[], T_Result],
        operations: typing.Callable[[], T_Result],
        request_body: typing.Callable[[], T_Result],
        provider_config: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is GetProviderCapabilitiesExpandOptions.CONNECTOR:
            return connector()
        if self is GetProviderCapabilitiesExpandOptions.OPERATIONS:
            return operations()
        if self is GetProviderCapabilitiesExpandOptions.REQUEST_BODY:
            return request_body()
        if self is GetProviderCapabilitiesExpandOptions.PROVIDER_CONFIG:
            return provider_config()
