# This file was auto-generated by Fern from our API Definition.

from .types import (
    ArmisCredential,
    ArmisCredential_Token,
    ArmisCredential_TokenId,
    AssetsArmisCentrix,
    AssetsArmisCentrixMock,
    AssetsArmisDataset,
    AssetsAxonius,
    AssetsCrowdStrike,
    AssetsNozomiVantage,
    AssetsNozomiVantageDataset,
    AssetsNozomiVantageMock,
    AssetsQualysCloud,
    AssetsQualysCloudDataset,
    AssetsQualysCloudMock,
    AssetsServiceNow,
    AssetsServiceNowDataset,
    AssetsServiceNowMock,
    AssetsSevco,
    AssetsTaniumCloud,
    AssetsTaniumCloudDataset,
    AssetsTaniumCloudMock,
    AutotaskApiIntegrationCodeCredential,
    AutotaskApiIntegrationCodeCredential_Secret,
    AutotaskApiIntegrationCodeCredential_SecretId,
    AutotaskSecretCredential,
    AutotaskSecretCredential_Secret,
    AutotaskSecretCredential_SecretId,
    AwsS3Credential,
    AwsS3Credential_Aws,
    AwsS3Credential_AwsId,
    AwsSecurityLakeCredential,
    AwsSecurityLakeCredential_Aws,
    AwsSecurityLakeCredential_AwsId,
    AwsSqsCredential,
    AwsSqsCredential_Aws,
    AwsSqsCredential_AwsId,
    AxoniusCredential,
    AxoniusCredential_Basic,
    AxoniusCredential_BasicId,
    AzureBlobCredential,
    AzureBlobCredential_Token,
    AzureBlobCredential_TokenId,
    AzureMonitorLogsCredential,
    AzureMonitorLogsCredential_Token,
    AzureMonitorLogsCredential_TokenId,
    CloudSecurityCrowdStrike,
    CloudSecurityDefender,
    CrowdStrikeCredential,
    CrowdStrikeCredential_OAuthClient,
    CrowdStrikeCredential_OAuthClientId,
    CrowdstrikeHecCredential,
    CrowdstrikeHecCredential_Token,
    CrowdstrikeHecCredential_TokenId,
    CustomFieldMapping,
    DefenderCredential,
    DefenderCredential_OAuthClient,
    DefenderCredential_OAuthClientId,
    EdrCrowdStrike,
    EdrDefender,
    EdrMalwarebytes,
    EdrSentinelOne,
    EdrSophos,
    ElasticsearchAuthOptions,
    ElasticsearchCredential,
    ElasticsearchCredential_Basic,
    ElasticsearchCredential_BasicId,
    ElasticsearchCredential_OAuthClient,
    ElasticsearchCredential_OAuthClientId,
    ElasticsearchCredential_Token,
    ElasticsearchCredential_TokenId,
    ElasticsearchSharedSecret,
    ElasticsearchSharedSecret_Secret,
    ElasticsearchSharedSecret_SecretId,
    EntraIdCredential,
    EntraIdCredential_OAuthClient,
    EntraIdCredential_OAuthClientId,
    FreshdeskCredential,
    FreshdeskCredential_Token,
    FreshdeskCredential_TokenId,
    GcsCredential,
    GcsCredential_Aws,
    GcsCredential_AwsId,
    GoogleChronicleCredential,
    GoogleChronicleCredential_OAuthClient,
    GoogleChronicleCredential_OAuthClientId,
    GoogleCredential,
    GoogleCredential_OAuthClient,
    GoogleCredential_OAuthClientId,
    GoogleServiceAccountCredential,
    GoogleServiceAccountCredential_OAuthClient,
    GoogleServiceAccountCredential_OAuthClientId,
    IdentityEntraId,
    IdentityGoogle,
    IdentityOkta,
    IdentityPingOne,
    JiraCredential,
    JiraCredential_Basic,
    JiraCredential_BasicId,
    MalwarebytesCredential,
    MalwarebytesCredential_OAuthClient,
    MalwarebytesCredential_OAuthClientId,
    NotificationsJira,
    NotificationsMock,
    NotificationsSlack,
    NotificationsSlackWebhook,
    NotificationsTeams,
    NozomiVantageCredential,
    NozomiVantageCredential_Basic,
    NozomiVantageCredential_BasicId,
    NucleusCredential,
    NucleusCredential_Token,
    NucleusCredential_TokenId,
    OktaCredential,
    OktaCredential_OAuthClient,
    OktaCredential_OAuthClientId,
    OktaCredential_Token,
    OktaCredential_TokenId,
    OpenSearchCredential,
    OpenSearchCredential_Basic,
    OpenSearchCredential_BasicId,
    PagerDutyCredential,
    PagerDutyCredential_Token,
    PagerDutyCredential_TokenId,
    PingOneCredential,
    PingOneCredential_Token,
    PingOneCredential_TokenId,
    ProviderConfig,
    ProviderConfigId,
    ProviderConfig_AssetsArmisCentrix,
    ProviderConfig_AssetsArmisCentrixMock,
    ProviderConfig_AssetsAxonius,
    ProviderConfig_AssetsCrowdstrike,
    ProviderConfig_AssetsNozomiVantage,
    ProviderConfig_AssetsNozomiVantageMock,
    ProviderConfig_AssetsQualysCloud,
    ProviderConfig_AssetsQualysCloudMock,
    ProviderConfig_AssetsServicenow,
    ProviderConfig_AssetsServicenowMock,
    ProviderConfig_AssetsSevco,
    ProviderConfig_AssetsTaniumCloud,
    ProviderConfig_AssetsTaniumCloudMock,
    ProviderConfig_CloudsecurityCrowdstrike,
    ProviderConfig_CloudsecurityDefender,
    ProviderConfig_EdrCrowdstrike,
    ProviderConfig_EdrDefender,
    ProviderConfig_EdrMalwarebytes,
    ProviderConfig_EdrSentinelone,
    ProviderConfig_EdrSophos,
    ProviderConfig_IdentityEntraId,
    ProviderConfig_IdentityGoogle,
    ProviderConfig_IdentityOkta,
    ProviderConfig_IdentityPingone,
    ProviderConfig_NotificationsJira,
    ProviderConfig_NotificationsMockNotifications,
    ProviderConfig_NotificationsSlack,
    ProviderConfig_NotificationsSlackWebhook,
    ProviderConfig_NotificationsTeams,
    ProviderConfig_SiemCrowdstrike,
    ProviderConfig_SiemElasticsearch,
    ProviderConfig_SiemGoogleChronicle,
    ProviderConfig_SiemGoogleSecurityOperations,
    ProviderConfig_SiemMockSiem,
    ProviderConfig_SiemOpensearch,
    ProviderConfig_SiemQRadar,
    ProviderConfig_SiemRapid7Insightidr,
    ProviderConfig_SiemSentinel,
    ProviderConfig_SiemSplunk,
    ProviderConfig_SiemSumoLogic,
    ProviderConfig_SinkAwsSecurityLake,
    ProviderConfig_SinkAwsSqs,
    ProviderConfig_SinkAzureMonitorLogs,
    ProviderConfig_SinkCrowdstrikeHec,
    ProviderConfig_SinkElasticsearch,
    ProviderConfig_SinkGoogleSecOps,
    ProviderConfig_SinkGoogleSecurityOperations,
    ProviderConfig_SinkMockSink,
    ProviderConfig_SinkOpensearch,
    ProviderConfig_SinkSplunk,
    ProviderConfig_StorageAwsS3,
    ProviderConfig_StorageAzureBlob,
    ProviderConfig_StorageGcs,
    ProviderConfig_StorageMockStorage,
    ProviderConfig_TicketingAutotask,
    ProviderConfig_TicketingFreshdesk,
    ProviderConfig_TicketingJira,
    ProviderConfig_TicketingMockTicketing,
    ProviderConfig_TicketingPagerduty,
    ProviderConfig_TicketingServicenow,
    ProviderConfig_TicketingServicenowSir,
    ProviderConfig_TicketingTorq,
    ProviderConfig_TicketingZendesk,
    ProviderConfig_VulnerabilitiesCrowdstrike,
    ProviderConfig_VulnerabilitiesNucleus,
    ProviderConfig_VulnerabilitiesQualysCloud,
    ProviderConfig_VulnerabilitiesQualysCloudMock,
    ProviderConfig_VulnerabilitiesRapid7InsightCloud,
    ProviderConfig_VulnerabilitiesRapid7InsightCloudMock,
    ProviderConfig_VulnerabilitiesTaniumCloud,
    ProviderConfig_VulnerabilitiesTaniumCloudMock,
    ProviderConfig_VulnerabilitiesTenableCloud,
    QRadarCredential,
    QRadarCredential_Token,
    QRadarCredential_TokenId,
    QualysCloudCredential,
    QualysCloudCredential_Basic,
    QualysCloudCredential_BasicId,
    Rapid7InsightCloudCredential,
    Rapid7InsightCloudCredential_Token,
    Rapid7InsightCloudCredential_TokenId,
    SentinelCredential,
    SentinelCredential_OAuthClient,
    SentinelCredential_OAuthClientId,
    SentinelOneCredential,
    SentinelOneCredential_Token,
    SentinelOneCredential_TokenId,
    SentinelOneEdrEventsCredential,
    SentinelOneEdrEventsCredential_Token,
    SentinelOneEdrEventsCredential_TokenId,
    ServiceNowCredential,
    ServiceNowCredential_Basic,
    ServiceNowCredential_BasicId,
    ServiceNowCredential_Token,
    ServiceNowCredential_TokenId,
    SevcoCredential,
    SevcoCredential_Token,
    SevcoCredential_TokenId,
    SiemCrowdstrike,
    SiemElasticsearch,
    SiemGoogleChronicle,
    SiemGoogleSecurityOperations,
    SiemMock,
    SiemOpenSearch,
    SiemQRadar,
    SiemRapid7InsightIdr,
    SiemSentinel,
    SiemSplunk,
    SiemSumoLogic,
    SinkAwsSecurityLake,
    SinkAwsSqs,
    SinkAzureMonitorLogs,
    SinkCrowdstrikeHec,
    SinkElasticsearch,
    SinkGoogleSecOps,
    SinkGoogleSecurityOperations,
    SinkMock,
    SinkOpenSearch,
    SinkSplunk,
    SlackCredential,
    SlackCredential_Token,
    SlackCredential_TokenId,
    SlackWebhookCredential,
    SlackWebhookCredential_Secret,
    SlackWebhookCredential_SecretId,
    SophosCredential,
    SophosCredential_OAuthClient,
    SophosCredential_OAuthClientId,
    SplunkHecToken,
    SplunkHecToken_Token,
    SplunkHecToken_TokenId,
    SplunkSearchCredential,
    SplunkSearchCredential_Token,
    SplunkSearchCredential_TokenId,
    StorageAwsS3,
    StorageAzureBlob,
    StorageGcs,
    StorageMock,
    SumoLogicCollectionUrl,
    SumoLogicCollectionUrl_Secret,
    SumoLogicCollectionUrl_SecretId,
    SumoLogicCredential,
    SumoLogicCredential_Basic,
    SumoLogicCredential_BasicId,
    TaniumCloudCredential,
    TaniumCloudCredential_Token,
    TaniumCloudCredential_TokenId,
    TeamsCredential,
    TeamsCredential_OAuthClient,
    TeamsCredential_OAuthClientId,
    TeamsCredential_WebhookUrl,
    TeamsCredential_WebhookUrlId,
    TenableCloudCredential,
    TenableCloudCredential_Token,
    TenableCloudCredential_TokenId,
    TicketingAutotask,
    TicketingFreshdesk,
    TicketingJira,
    TicketingMock,
    TicketingPagerDuty,
    TicketingServiceNow,
    TicketingServiceNowSir,
    TicketingTorq,
    TicketingZendesk,
    TorqCredential,
    TorqCredential_OAuthClient,
    TorqCredential_OAuthClientId,
    VulnerabilitiesCrowdStrike,
    VulnerabilitiesNucleus,
    VulnerabilitiesQualysCloud,
    VulnerabilitiesQualysCloudDataset,
    VulnerabilitiesQualysCloudMock,
    VulnerabilitiesRapid7InsightCloud,
    VulnerabilitiesRapid7InsightCloudDataset,
    VulnerabilitiesRapid7InsightCloudMock,
    VulnerabilitiesTaniumCloud,
    VulnerabilitiesTaniumCloudDataset,
    VulnerabilitiesTaniumCloudMock,
    VulnerabilitiesTenableCloud,
    ZendeskCredential,
    ZendeskCredential_Basic,
    ZendeskCredential_BasicId,
)

__all__ = [
    "ArmisCredential",
    "ArmisCredential_Token",
    "ArmisCredential_TokenId",
    "AssetsArmisCentrix",
    "AssetsArmisCentrixMock",
    "AssetsArmisDataset",
    "AssetsAxonius",
    "AssetsCrowdStrike",
    "AssetsNozomiVantage",
    "AssetsNozomiVantageDataset",
    "AssetsNozomiVantageMock",
    "AssetsQualysCloud",
    "AssetsQualysCloudDataset",
    "AssetsQualysCloudMock",
    "AssetsServiceNow",
    "AssetsServiceNowDataset",
    "AssetsServiceNowMock",
    "AssetsSevco",
    "AssetsTaniumCloud",
    "AssetsTaniumCloudDataset",
    "AssetsTaniumCloudMock",
    "AutotaskApiIntegrationCodeCredential",
    "AutotaskApiIntegrationCodeCredential_Secret",
    "AutotaskApiIntegrationCodeCredential_SecretId",
    "AutotaskSecretCredential",
    "AutotaskSecretCredential_Secret",
    "AutotaskSecretCredential_SecretId",
    "AwsS3Credential",
    "AwsS3Credential_Aws",
    "AwsS3Credential_AwsId",
    "AwsSecurityLakeCredential",
    "AwsSecurityLakeCredential_Aws",
    "AwsSecurityLakeCredential_AwsId",
    "AwsSqsCredential",
    "AwsSqsCredential_Aws",
    "AwsSqsCredential_AwsId",
    "AxoniusCredential",
    "AxoniusCredential_Basic",
    "AxoniusCredential_BasicId",
    "AzureBlobCredential",
    "AzureBlobCredential_Token",
    "AzureBlobCredential_TokenId",
    "AzureMonitorLogsCredential",
    "AzureMonitorLogsCredential_Token",
    "AzureMonitorLogsCredential_TokenId",
    "CloudSecurityCrowdStrike",
    "CloudSecurityDefender",
    "CrowdStrikeCredential",
    "CrowdStrikeCredential_OAuthClient",
    "CrowdStrikeCredential_OAuthClientId",
    "CrowdstrikeHecCredential",
    "CrowdstrikeHecCredential_Token",
    "CrowdstrikeHecCredential_TokenId",
    "CustomFieldMapping",
    "DefenderCredential",
    "DefenderCredential_OAuthClient",
    "DefenderCredential_OAuthClientId",
    "EdrCrowdStrike",
    "EdrDefender",
    "EdrMalwarebytes",
    "EdrSentinelOne",
    "EdrSophos",
    "ElasticsearchAuthOptions",
    "ElasticsearchCredential",
    "ElasticsearchCredential_Basic",
    "ElasticsearchCredential_BasicId",
    "ElasticsearchCredential_OAuthClient",
    "ElasticsearchCredential_OAuthClientId",
    "ElasticsearchCredential_Token",
    "ElasticsearchCredential_TokenId",
    "ElasticsearchSharedSecret",
    "ElasticsearchSharedSecret_Secret",
    "ElasticsearchSharedSecret_SecretId",
    "EntraIdCredential",
    "EntraIdCredential_OAuthClient",
    "EntraIdCredential_OAuthClientId",
    "FreshdeskCredential",
    "FreshdeskCredential_Token",
    "FreshdeskCredential_TokenId",
    "GcsCredential",
    "GcsCredential_Aws",
    "GcsCredential_AwsId",
    "GoogleChronicleCredential",
    "GoogleChronicleCredential_OAuthClient",
    "GoogleChronicleCredential_OAuthClientId",
    "GoogleCredential",
    "GoogleCredential_OAuthClient",
    "GoogleCredential_OAuthClientId",
    "GoogleServiceAccountCredential",
    "GoogleServiceAccountCredential_OAuthClient",
    "GoogleServiceAccountCredential_OAuthClientId",
    "IdentityEntraId",
    "IdentityGoogle",
    "IdentityOkta",
    "IdentityPingOne",
    "JiraCredential",
    "JiraCredential_Basic",
    "JiraCredential_BasicId",
    "MalwarebytesCredential",
    "MalwarebytesCredential_OAuthClient",
    "MalwarebytesCredential_OAuthClientId",
    "NotificationsJira",
    "NotificationsMock",
    "NotificationsSlack",
    "NotificationsSlackWebhook",
    "NotificationsTeams",
    "NozomiVantageCredential",
    "NozomiVantageCredential_Basic",
    "NozomiVantageCredential_BasicId",
    "NucleusCredential",
    "NucleusCredential_Token",
    "NucleusCredential_TokenId",
    "OktaCredential",
    "OktaCredential_OAuthClient",
    "OktaCredential_OAuthClientId",
    "OktaCredential_Token",
    "OktaCredential_TokenId",
    "OpenSearchCredential",
    "OpenSearchCredential_Basic",
    "OpenSearchCredential_BasicId",
    "PagerDutyCredential",
    "PagerDutyCredential_Token",
    "PagerDutyCredential_TokenId",
    "PingOneCredential",
    "PingOneCredential_Token",
    "PingOneCredential_TokenId",
    "ProviderConfig",
    "ProviderConfigId",
    "ProviderConfig_AssetsArmisCentrix",
    "ProviderConfig_AssetsArmisCentrixMock",
    "ProviderConfig_AssetsAxonius",
    "ProviderConfig_AssetsCrowdstrike",
    "ProviderConfig_AssetsNozomiVantage",
    "ProviderConfig_AssetsNozomiVantageMock",
    "ProviderConfig_AssetsQualysCloud",
    "ProviderConfig_AssetsQualysCloudMock",
    "ProviderConfig_AssetsServicenow",
    "ProviderConfig_AssetsServicenowMock",
    "ProviderConfig_AssetsSevco",
    "ProviderConfig_AssetsTaniumCloud",
    "ProviderConfig_AssetsTaniumCloudMock",
    "ProviderConfig_CloudsecurityCrowdstrike",
    "ProviderConfig_CloudsecurityDefender",
    "ProviderConfig_EdrCrowdstrike",
    "ProviderConfig_EdrDefender",
    "ProviderConfig_EdrMalwarebytes",
    "ProviderConfig_EdrSentinelone",
    "ProviderConfig_EdrSophos",
    "ProviderConfig_IdentityEntraId",
    "ProviderConfig_IdentityGoogle",
    "ProviderConfig_IdentityOkta",
    "ProviderConfig_IdentityPingone",
    "ProviderConfig_NotificationsJira",
    "ProviderConfig_NotificationsMockNotifications",
    "ProviderConfig_NotificationsSlack",
    "ProviderConfig_NotificationsSlackWebhook",
    "ProviderConfig_NotificationsTeams",
    "ProviderConfig_SiemCrowdstrike",
    "ProviderConfig_SiemElasticsearch",
    "ProviderConfig_SiemGoogleChronicle",
    "ProviderConfig_SiemGoogleSecurityOperations",
    "ProviderConfig_SiemMockSiem",
    "ProviderConfig_SiemOpensearch",
    "ProviderConfig_SiemQRadar",
    "ProviderConfig_SiemRapid7Insightidr",
    "ProviderConfig_SiemSentinel",
    "ProviderConfig_SiemSplunk",
    "ProviderConfig_SiemSumoLogic",
    "ProviderConfig_SinkAwsSecurityLake",
    "ProviderConfig_SinkAwsSqs",
    "ProviderConfig_SinkAzureMonitorLogs",
    "ProviderConfig_SinkCrowdstrikeHec",
    "ProviderConfig_SinkElasticsearch",
    "ProviderConfig_SinkGoogleSecOps",
    "ProviderConfig_SinkGoogleSecurityOperations",
    "ProviderConfig_SinkMockSink",
    "ProviderConfig_SinkOpensearch",
    "ProviderConfig_SinkSplunk",
    "ProviderConfig_StorageAwsS3",
    "ProviderConfig_StorageAzureBlob",
    "ProviderConfig_StorageGcs",
    "ProviderConfig_StorageMockStorage",
    "ProviderConfig_TicketingAutotask",
    "ProviderConfig_TicketingFreshdesk",
    "ProviderConfig_TicketingJira",
    "ProviderConfig_TicketingMockTicketing",
    "ProviderConfig_TicketingPagerduty",
    "ProviderConfig_TicketingServicenow",
    "ProviderConfig_TicketingServicenowSir",
    "ProviderConfig_TicketingTorq",
    "ProviderConfig_TicketingZendesk",
    "ProviderConfig_VulnerabilitiesCrowdstrike",
    "ProviderConfig_VulnerabilitiesNucleus",
    "ProviderConfig_VulnerabilitiesQualysCloud",
    "ProviderConfig_VulnerabilitiesQualysCloudMock",
    "ProviderConfig_VulnerabilitiesRapid7InsightCloud",
    "ProviderConfig_VulnerabilitiesRapid7InsightCloudMock",
    "ProviderConfig_VulnerabilitiesTaniumCloud",
    "ProviderConfig_VulnerabilitiesTaniumCloudMock",
    "ProviderConfig_VulnerabilitiesTenableCloud",
    "QRadarCredential",
    "QRadarCredential_Token",
    "QRadarCredential_TokenId",
    "QualysCloudCredential",
    "QualysCloudCredential_Basic",
    "QualysCloudCredential_BasicId",
    "Rapid7InsightCloudCredential",
    "Rapid7InsightCloudCredential_Token",
    "Rapid7InsightCloudCredential_TokenId",
    "SentinelCredential",
    "SentinelCredential_OAuthClient",
    "SentinelCredential_OAuthClientId",
    "SentinelOneCredential",
    "SentinelOneCredential_Token",
    "SentinelOneCredential_TokenId",
    "SentinelOneEdrEventsCredential",
    "SentinelOneEdrEventsCredential_Token",
    "SentinelOneEdrEventsCredential_TokenId",
    "ServiceNowCredential",
    "ServiceNowCredential_Basic",
    "ServiceNowCredential_BasicId",
    "ServiceNowCredential_Token",
    "ServiceNowCredential_TokenId",
    "SevcoCredential",
    "SevcoCredential_Token",
    "SevcoCredential_TokenId",
    "SiemCrowdstrike",
    "SiemElasticsearch",
    "SiemGoogleChronicle",
    "SiemGoogleSecurityOperations",
    "SiemMock",
    "SiemOpenSearch",
    "SiemQRadar",
    "SiemRapid7InsightIdr",
    "SiemSentinel",
    "SiemSplunk",
    "SiemSumoLogic",
    "SinkAwsSecurityLake",
    "SinkAwsSqs",
    "SinkAzureMonitorLogs",
    "SinkCrowdstrikeHec",
    "SinkElasticsearch",
    "SinkGoogleSecOps",
    "SinkGoogleSecurityOperations",
    "SinkMock",
    "SinkOpenSearch",
    "SinkSplunk",
    "SlackCredential",
    "SlackCredential_Token",
    "SlackCredential_TokenId",
    "SlackWebhookCredential",
    "SlackWebhookCredential_Secret",
    "SlackWebhookCredential_SecretId",
    "SophosCredential",
    "SophosCredential_OAuthClient",
    "SophosCredential_OAuthClientId",
    "SplunkHecToken",
    "SplunkHecToken_Token",
    "SplunkHecToken_TokenId",
    "SplunkSearchCredential",
    "SplunkSearchCredential_Token",
    "SplunkSearchCredential_TokenId",
    "StorageAwsS3",
    "StorageAzureBlob",
    "StorageGcs",
    "StorageMock",
    "SumoLogicCollectionUrl",
    "SumoLogicCollectionUrl_Secret",
    "SumoLogicCollectionUrl_SecretId",
    "SumoLogicCredential",
    "SumoLogicCredential_Basic",
    "SumoLogicCredential_BasicId",
    "TaniumCloudCredential",
    "TaniumCloudCredential_Token",
    "TaniumCloudCredential_TokenId",
    "TeamsCredential",
    "TeamsCredential_OAuthClient",
    "TeamsCredential_OAuthClientId",
    "TeamsCredential_WebhookUrl",
    "TeamsCredential_WebhookUrlId",
    "TenableCloudCredential",
    "TenableCloudCredential_Token",
    "TenableCloudCredential_TokenId",
    "TicketingAutotask",
    "TicketingFreshdesk",
    "TicketingJira",
    "TicketingMock",
    "TicketingPagerDuty",
    "TicketingServiceNow",
    "TicketingServiceNowSir",
    "TicketingTorq",
    "TicketingZendesk",
    "TorqCredential",
    "TorqCredential_OAuthClient",
    "TorqCredential_OAuthClientId",
    "VulnerabilitiesCrowdStrike",
    "VulnerabilitiesNucleus",
    "VulnerabilitiesQualysCloud",
    "VulnerabilitiesQualysCloudDataset",
    "VulnerabilitiesQualysCloudMock",
    "VulnerabilitiesRapid7InsightCloud",
    "VulnerabilitiesRapid7InsightCloudDataset",
    "VulnerabilitiesRapid7InsightCloudMock",
    "VulnerabilitiesTaniumCloud",
    "VulnerabilitiesTaniumCloudDataset",
    "VulnerabilitiesTaniumCloudMock",
    "VulnerabilitiesTenableCloud",
    "ZendeskCredential",
    "ZendeskCredential_Basic",
    "ZendeskCredential_BasicId",
]
